# This RPM spec file exists primarily to enable CI/CD pipelines and automatic
# testing of built RPMs. This RPM can be used as a suitable baseline for a
# proper distribution package, but changes should be made to suit the needs of
# the package.

%bcond_without check
%bcond_without install_examples

%global forgeurl https://github.com/RedHatInsights/libygg
%global commit   ec07277
Version:         0.1.0

%forgemeta

# Manually redefine %%dist to work around an issue in COPR where the build root
# that creates the srpm does not define a value for %%dist. This should *NOT* be
# carried in downstream; this is strictly an upstream/COPR/CI workaround.
%if "%{dist}" == ""
%global dist %{distprefix}.fc%{fedora}
%endif

%global common_description %{expand:
libygg is a GObject-based library providing an API for applications to interact
with yggdrasil.}

Name:           libygg
Release:        0%{?dist}
Summary:        GObject yggdrasil client library

License:        GPL-3.0-only
URL:            %{forgeurl}
Source:         %{forgesource}

BuildRequires:  gcc
BuildRequires:  meson >= 0.58.2
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-2.0) >= 2.56.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  yggdrasil >= 0.3.2
%if %{with check}
BuildRequires:  /usr/bin/dbus-daemon
%endif

%description %{common_description}

%package devel
Summary:        Development libraries and header files for %{name}
Requires:       %{name}%{?_isa} = %{?epoch:%{epoch}:}%{version}-%{release}

%description devel
%{common_description}

%{summary}.

%if %{with install_examples}
%package examples
Summary:       Example workers using libygg
Requires:      %{name}%{?_isa} = %{?epoch:%{epoch}:}%{version}-%{release}

%description examples
%{common_description}

%{summary}.
%endif

%prep
%forgesetup

%build
%meson %{?with_install_examples:-Dinstall_examples=True}
%meson_build

%install
%meson_install

%if %{with check}
%check
%meson_test
%endif

%files
%license COPYING
%doc README.md
%{_libdir}/%{name}*.so.*
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/*.typelib

%files devel
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/*.gir
%{_includedir}/%{name}*/*.h
%{_libdir}/%{name}*.so
%{_libdir}/pkgconfig/*.pc

%if %{with install_examples}
%files examples
%{_bindir}/yggdrasil-worker-*
%{_datadir}/dbus-1/system-services/*
%{_datadir}/dbus-1/system.d/*.conf
%endif
